Security Advisories (1)
CVE-2026-5085 (2026-04-13)

Solstice::Session versions through 1440 for Perl generates session ids insecurely. The _generateSessionID method returns an MD5 digest seeded by the epoch time, a random hash reference, a call to the built-in rand() function and the process id. The same method is used in the _generateID method in Solstice::Subsession, which is part of the same distribution. The epoch time may be guessed, if it is not leaked in the HTTP Date header. Stringified hash refences will contain predictable content. The built-in rand() function is seeded by 16-bits and is unsuitable for security purposes. The process id comes from a small set of numbers. Predictable session ids could allow an attacker to gain access to systems.

NAME

Solstice::Application - An object representing a Solstice application.

SYNOPSIS

# This is always subclassed, enhanced with accessors for data relevent to a specific instantiation of an application.
use Solstice::Application;
my $application = new Solstice::Application($app_name);
my $name = $application->getName();
my $version = $application->getVersion();
my $namespace = $application->getNamespace();

# Returns the StateTracker object for this instantiation of an application.
my $state = $application->getState();

# This can be used to put data personalized to the screen in the breadcrumbing.
my $breadcrumb_info = $application->getStatePersonalInfo();

DESCRIPTION

Export

No symbols exported.

Methods

new()

Creates a new Solstice::Application object.

getNavigationView()

Attempts to return the application's navigation view. Should be overridden in the subclass for custom behavior. This will be called unless some application code explicitly sets a navigation view.

Private Methods

_init($id) =item _init($name)

Initialize the application object

_getAccessorDefinition()

Modules Used

Solstice::Database.

AUTHOR

Catalyst Group, <catalyst@u.washington.edu>

VERSION

$Revision: 3364 $

COPYRIGHT

Copyright 1998-2007 Office of Learning Technologies, University of Washington

Licensed under the Educational Community License, Version 1.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at: http://www.opensource.org/licenses/ecl1.php

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.