Security Advisories (1)
CVE-2026-5085 (2026-04-13)

Solstice::Session versions through 1440 for Perl generates session ids insecurely. The _generateSessionID method returns an MD5 digest seeded by the epoch time, a random hash reference, a call to the built-in rand() function and the process id. The same method is used in the _generateID method in Solstice::Subsession, which is part of the same distribution. The epoch time may be guessed, if it is not leaked in the HTTP Date header. Stringified hash refences will contain predictable content. The built-in rand() function is seeded by 16-bits and is unsuitable for security purposes. The process id comes from a small set of numbers. Predictable session ids could allow an attacker to gain access to systems.

NAME

Solstice::LogService - Provides a centralized logging facility to applications.

SYNOPSIS

$self->getLogService()->log({
    content     => 'User did blah',     #the content of the log message
    namespace   => 'appname',           #optional - the directory in the data root to use - defaults to the app's namespace
    username    => 'mcrawfor',          #optional - current user is pulled from userservice if not provided
    log_file    => 'blah_log',          #optional - defaults to 'log';
    model       => $model->getName(),   #Optional - a textual description of a model
    model_id    => $model->getID(),     #optional - the id of the model in question

DESCRIPTION

Superclass

Solstice::Service

Export

No symbols exported.

Methods

new([$namespace])

Creates a new Solstice::LogService object.

log(\%params)
logAnonymous(\%params)

This is equivalent to log(), but the username and timestamp won't be passed on to the logging modules

add(\%params)

Alias for log().

Private Methods

_dispatch($message)
_getClassName()

Return the class name. Overridden to avoid a ref() in the superclass.

Modules Used

Solstice::Service, Solstice::Model::LogMessage.

AUTHOR

Catalyst Group, <catalyst@u.washington.edu>

VERSION

$Revision: 3364 $

COPYRIGHT

Copyright 1998-2007 Office of Learning Technologies, University of Washington

Licensed under the Educational Community License, Version 1.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at: http://www.opensource.org/licenses/ecl1.php

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.